@@ -123,6 +123,7 @@ enum {
 	COL_ACCOUNT_COUNT
 };
 
+static void     account_chooser_constructed            (GObject                  *object);
 static void     account_chooser_finalize               (GObject                  *object);
 static void     account_chooser_get_property           (GObject                  *object,
 							guint                     param_id,
@@ -180,6 +181,7 @@ empathy_account_chooser_class_init (EmpathyAccountChooserClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
+	object_class->constructed = account_chooser_constructed;
 	object_class->finalize = account_chooser_finalize;
 	object_class->get_property = account_chooser_get_property;
 	object_class->set_property = account_chooser_set_property;
@@ -230,8 +232,14 @@ empathy_account_chooser_init (EmpathyAccountChooser *chooser)
 	g_signal_connect (priv->manager, "account-removed",
 			  G_CALLBACK (account_chooser_account_removed_cb),
 			  chooser);
+}
 
-	account_chooser_setup (EMPATHY_ACCOUNT_CHOOSER (chooser));
+static void
+account_chooser_constructed (GObject *object)
+{
+	EmpathyAccountChooser *self = (EmpathyAccountChooser *) object;
+
+	account_chooser_setup (self);
 }
 
 static void
@@ -276,10 +284,6 @@ account_chooser_set_property (GObject      *object,
 			      const GValue *value,
 			      GParamSpec   *pspec)
 {
-	EmpathyAccountChooserPriv *priv;
-
-	priv = GET_PRIV (object);
-
 	switch (param_id) {
 	case PROP_HAS_ALL_OPTION:
 		empathy_account_chooser_set_has_all_option (EMPATHY_ACCOUNT_CHOOSER (object),
@@ -321,15 +325,12 @@ empathy_account_chooser_new (void)
 TpAccount *
 empathy_account_chooser_dup_account (EmpathyAccountChooser *chooser)
 {
-	EmpathyAccountChooserPriv *priv;
 	TpAccount                 *account;
 	GtkTreeModel             *model;
 	GtkTreeIter               iter;
 
 	g_return_val_if_fail (EMPATHY_IS_ACCOUNT_CHOOSER (chooser), NULL);
 
-	priv = GET_PRIV (chooser);
-
 	model = gtk_combo_box_get_model (GTK_COMBO_BOX (chooser));
 	if (!gtk_combo_box_get_active_iter (GTK_COMBO_BOX (chooser), &iter)) {
 		return NULL;
@@ -354,14 +355,11 @@ empathy_account_chooser_dup_account (EmpathyAccountChooser *chooser)
 TpConnection *
 empathy_account_chooser_get_connection (EmpathyAccountChooser *chooser)
 {
-	EmpathyAccountChooserPriv *priv;
 	TpAccount                 *account;
 	TpConnection              *connection;
 
 	g_return_val_if_fail (EMPATHY_IS_ACCOUNT_CHOOSER (chooser), NULL);
 
-	priv = GET_PRIV (chooser);
-
 	account = empathy_account_chooser_dup_account (chooser);
 
 	/* if the returned account is NULL, then the account manager probably
