@@ -40,13 +40,14 @@
 
 #include <libempathy/empathy-individual-manager.h>
 #include <libempathy/empathy-contact-groups.h>
-#include <libempathy/empathy-dispatcher.h>
+#include <libempathy/empathy-request-util.h>
 #include <libempathy/empathy-utils.h>
 
 #include "empathy-individual-view.h"
 #include "empathy-individual-menu.h"
 #include "empathy-individual-store.h"
 #include "empathy-contact-dialogs.h"
+#include "empathy-individual-dialogs.h"
 #include "empathy-images.h"
 #include "empathy-linking-dialog.h"
 #include "empathy-cell-renderer-expander.h"
@@ -239,10 +240,10 @@ groups_change_group_cb (GObject *source,
     GAsyncResult *result,
     gpointer user_data)
 {
-  FolksGroupable *groupable = FOLKS_GROUPABLE (source);
+  FolksGroupDetails *group_details = FOLKS_GROUP_DETAILS (source);
   GError *error = NULL;
 
-  folks_groupable_change_group_finish (groupable, result, &error);
+  folks_group_details_change_group_finish (group_details, result, &error);
   if (error != NULL)
     {
       g_warning ("failed to change group: %s", error->message);
@@ -373,14 +374,16 @@ real_drag_individual_received_cb (EmpathyIndividualView *self,
   if (!tp_strdiff (new_group, EMPATHY_INDIVIDUAL_STORE_FAVORITE))
     {
       /* Mark contact as favourite */
-      folks_favouritable_set_is_favourite (FOLKS_FAVOURITABLE (individual), TRUE);
+      folks_favourite_details_set_is_favourite (
+          FOLKS_FAVOURITE_DETAILS (individual), TRUE);
       return;
     }
 
   if (!tp_strdiff (old_group, EMPATHY_INDIVIDUAL_STORE_FAVORITE))
     {
       /* Remove contact as favourite */
-      folks_favouritable_set_is_favourite (FOLKS_FAVOURITABLE (individual), FALSE);
+      folks_favourite_details_set_is_favourite (
+          FOLKS_FAVOURITE_DETAILS (individual), FALSE);
 
       /* Don't try to remove it */
       old_group = NULL;
@@ -388,14 +391,14 @@ real_drag_individual_received_cb (EmpathyIndividualView *self,
 
   if (new_group != NULL)
     {
-      folks_groupable_change_group (FOLKS_GROUPABLE (individual), new_group, TRUE,
-          groups_change_group_cb, NULL);
+      folks_group_details_change_group (FOLKS_GROUP_DETAILS (individual),
+          new_group, TRUE, groups_change_group_cb, NULL);
     }
 
   if (old_group != NULL && action == GDK_ACTION_MOVE)
     {
-      folks_groupable_change_group (FOLKS_GROUPABLE (individual), old_group,
-          FALSE, groups_change_group_cb, NULL);
+      folks_group_details_change_group (FOLKS_GROUP_DETAILS (individual),
+          old_group, FALSE, groups_change_group_cb, NULL);
     }
 }
 
@@ -406,7 +409,6 @@ individual_view_persona_drag_received (GtkWidget *self,
     GtkTreePath *path,
     GtkSelectionData *selection)
 {
-  EmpathyIndividualViewPriv *priv;
   EmpathyIndividualManager *manager = NULL;
   FolksIndividual *individual = NULL;
   FolksPersona *persona = NULL;
@@ -414,8 +416,6 @@ individual_view_persona_drag_received (GtkWidget *self,
   GList *individuals, *l;
   gboolean retval = FALSE;
 
-  priv = GET_PRIV (self);
-
   persona_uid = (const gchar *) gtk_selection_data_get_data (selection);
 
   /* FIXME: This is slow, but the only way to find the Persona we're having
@@ -677,7 +677,8 @@ individual_view_drag_motion (GtkWidget *widget,
         }
 
       if (individual != NULL &&
-          folks_presence_owner_is_online (FOLKS_PRESENCE_OWNER (individual)) &&
+          folks_presence_details_is_online (
+              FOLKS_PRESENCE_DETAILS (individual)) &&
           (caps & EMPATHY_CAPABILITIES_FT))
         {
           gdk_drag_status (context, GDK_ACTION_COPY, time_);
@@ -1015,7 +1016,7 @@ individual_view_row_activated (GtkTreeView *view,
     {
       DEBUG ("Starting a chat");
 
-      empathy_dispatcher_chat_with_contact (contact,
+      empathy_chat_with_contact (contact,
           gtk_get_current_event_time ());
     }
 
@@ -1705,13 +1706,13 @@ individual_view_is_visible_individual (EmpathyIndividualView *self,
   if (contains_interesting_persona == FALSE)
     return FALSE;
 
-  is_favorite = folks_favouritable_get_is_favourite (
-      FOLKS_FAVOURITABLE (individual));
+  is_favorite = folks_favourite_details_get_is_favourite (
+      FOLKS_FAVOURITE_DETAILS (individual));
   if (is_searching == FALSE)
     return (priv->show_offline || is_online || is_favorite);
 
   /* check alias name */
-  str = folks_aliasable_get_alias (FOLKS_ALIASABLE (individual));
+  str = folks_alias_details_get_alias (FOLKS_ALIAS_DETAILS (individual));
 
   if (empathy_live_search_match (live, str))
     return TRUE;
@@ -2212,7 +2213,6 @@ empathy_individual_view_new (EmpathyIndividualStore *store,
 FolksIndividual *
 empathy_individual_view_dup_selected (EmpathyIndividualView *view)
 {
-  EmpathyIndividualViewPriv *priv;
   GtkTreeSelection *selection;
   GtkTreeIter iter;
   GtkTreeModel *model;
@@ -2220,8 +2220,6 @@ empathy_individual_view_dup_selected (EmpathyIndividualView *view)
 
   g_return_val_if_fail (EMPATHY_IS_INDIVIDUAL_VIEW (view), NULL);
 
-  priv = GET_PRIV (view);
-
   selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (view));
   if (!gtk_tree_selection_get_selected (selection, &model, &iter))
     return NULL;
@@ -2236,7 +2234,6 @@ static gchar *
 empathy_individual_view_dup_selected_group (EmpathyIndividualView *view,
     gboolean *is_fake_group)
 {
-  EmpathyIndividualViewPriv *priv;
   GtkTreeSelection *selection;
   GtkTreeIter iter;
   GtkTreeModel *model;
@@ -2246,8 +2243,6 @@ empathy_individual_view_dup_selected_group (EmpathyIndividualView *view,
 
   g_return_val_if_fail (EMPATHY_IS_INDIVIDUAL_VIEW (view), NULL);
 
-  priv = GET_PRIV (view);
-
   selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (view));
   if (!gtk_tree_selection_get_selected (selection, &model, &iter))
     return NULL;
@@ -2269,19 +2264,43 @@ empathy_individual_view_dup_selected_group (EmpathyIndividualView *view,
   return name;
 }
 
-static gboolean
+enum
+{
+  REMOVE_DIALOG_RESPONSE_CANCEL = 0,
+  REMOVE_DIALOG_RESPONSE_DELETE,
+  REMOVE_DIALOG_RESPONSE_DELETE_AND_BLOCK,
+};
+
+static int
 individual_view_remove_dialog_show (GtkWindow *parent,
     const gchar *message,
-    const gchar *secondary_text)
+    const gchar *secondary_text,
+    gboolean block_button)
 {
   GtkWidget *dialog;
   gboolean res;
 
   dialog = gtk_message_dialog_new (parent, GTK_DIALOG_MODAL,
       GTK_MESSAGE_QUESTION, GTK_BUTTONS_NONE, "%s", message);
+
+  if (block_button)
+    {
+      GtkWidget *button;
+
+      /* gtk_dialog_add_button() doesn't allow us to pass a string with a
+       * mnemonic so we have to create the button manually. */
+      button = gtk_button_new_with_mnemonic (
+          _("Delete and _Block"));
+
+      gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button,
+          REMOVE_DIALOG_RESPONSE_DELETE_AND_BLOCK);
+
+      gtk_widget_show (button);
+    }
+
   gtk_dialog_add_buttons (GTK_DIALOG (dialog),
-      GTK_STOCK_CANCEL, GTK_RESPONSE_NO,
-      GTK_STOCK_DELETE, GTK_RESPONSE_YES, NULL);
+      GTK_STOCK_CANCEL, REMOVE_DIALOG_RESPONSE_CANCEL,
+      GTK_STOCK_DELETE, REMOVE_DIALOG_RESPONSE_DELETE, NULL);
   gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
       "%s", secondary_text);
 
@@ -2290,7 +2309,7 @@ individual_view_remove_dialog_show (GtkWindow *parent,
   res = gtk_dialog_run (GTK_DIALOG (dialog));
   gtk_widget_destroy (dialog);
 
-  return (res == GTK_RESPONSE_YES);
+  return res;
 }
 
 static void
@@ -2310,7 +2329,7 @@ individual_view_group_remove_activate_cb (GtkMenuItem *menuitem,
           group);
       parent = empathy_get_toplevel_window (GTK_WIDGET (view));
       if (individual_view_remove_dialog_show (parent, _("Removing group"),
-              text))
+              text, FALSE) == REMOVE_DIALOG_RESPONSE_DELETE)
         {
           EmpathyIndividualManager *manager =
               empathy_individual_manager_dup_singleton ();
@@ -2389,10 +2408,13 @@ individual_view_remove_activate_cb (GtkMenuItem *menuitem,
 
   if (individual != NULL)
     {
+      EmpathyIndividualManager *manager;
       gchar *text;
       GtkWindow *parent;
       GList *l, *personas;
       guint persona_count = 0;
+      gboolean can_block;
+      int res;
 
       personas = folks_individual_get_personas (individual);
 
@@ -2415,7 +2437,8 @@ individual_view_remove_activate_cb (GtkMenuItem *menuitem,
           text =
               g_strdup_printf (
                   _("Do you really want to remove the contact '%s'?"),
-                  folks_aliasable_get_alias (FOLKS_ALIASABLE (individual)));
+                  folks_alias_details_get_alias (
+                      FOLKS_ALIAS_DETAILS (individual)));
         }
       else
         {
@@ -2425,23 +2448,40 @@ individual_view_remove_activate_cb (GtkMenuItem *menuitem,
                   _("Do you really want to remove the linked contact '%s'? "
                     "Note that this will remove all the contacts which make up "
                     "this linked contact."),
-                  folks_aliasable_get_alias (FOLKS_ALIASABLE (individual)));
+                  folks_alias_details_get_alias (
+                      FOLKS_ALIAS_DETAILS (individual)));
         }
 
+
+      manager = empathy_individual_manager_dup_singleton ();
+      can_block = empathy_individual_manager_supports_blocking (manager,
+          individual);
       parent = empathy_get_toplevel_window (GTK_WIDGET (view));
+      res = individual_view_remove_dialog_show (parent, _("Removing contact"),
+              text, can_block);
 
-      if (individual_view_remove_dialog_show (parent, _("Removing contact"),
-              text))
+      if (res == REMOVE_DIALOG_RESPONSE_DELETE ||
+          res == REMOVE_DIALOG_RESPONSE_DELETE_AND_BLOCK)
         {
-          EmpathyIndividualManager *manager;
+          gboolean abusive;
+
+          if (res == REMOVE_DIALOG_RESPONSE_DELETE_AND_BLOCK)
+            {
+              if (!empathy_block_individual_dialog_show (parent, individual,
+                    &abusive))
+                goto finally;
+
+              empathy_individual_manager_set_blocked (manager, individual,
+                  TRUE, abusive);
+            }
 
-          manager = empathy_individual_manager_dup_singleton ();
           empathy_individual_manager_remove (manager, individual, "");
-          g_object_unref (G_OBJECT (manager));
         }
 
+finally:
       g_free (text);
       g_object_unref (individual);
+      g_object_unref (manager);
     }
 }
 
