@@ -987,8 +987,22 @@ accounts_dialog_row_changed_foreach (GtkTreeModel *model,
     GtkTreeIter *iter,
     gpointer user_data)
 {
-  gtk_tree_model_row_changed (model, path, iter);
+  TpAccount *account;
 
+  gtk_tree_model_get (model, iter, COL_ACCOUNT, &account, -1);
+
+  if (account == NULL)
+    return FALSE;
+
+  if (tp_account_get_connection_status (account, NULL) ==
+      TP_CONNECTION_STATUS_CONNECTING)
+    {
+      /* Only update the row where we have a connecting account as that's the
+       * ones having a blinking icon. */
+      gtk_tree_model_row_changed (model, path, iter);
+    }
+
+  g_object_unref (account);
   return FALSE;
 }
 
@@ -1542,7 +1556,7 @@ accounts_dialog_treeview_button_press_event_cb (GtkTreeView *view,
   gtk_tree_model_get (model, &iter, COL_ACCOUNT, &account, -1);
 
   /* Create the menu */
-  menu = gtk_menu_new ();
+  menu = empathy_context_menu_new (GTK_WIDGET (view));
 
   /* Get images for menu items */
   image_enable = gtk_image_new_from_icon_name (empathy_icon_name_for_presence (
@@ -1929,7 +1943,20 @@ accounts_dialog_set_selected_account (EmpathyAccountsDialog *dialog,
 
   selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (priv->treeview));
   if (accounts_dialog_get_account_iter (dialog, account, &iter))
-    gtk_tree_selection_select_iter (selection, &iter);
+    {
+      GtkTreePath *path;
+      GtkTreeModel *model;
+
+      gtk_tree_selection_select_iter (selection, &iter);
+
+      model = gtk_tree_view_get_model (GTK_TREE_VIEW (priv->treeview));
+      path = gtk_tree_model_get_path (model, &iter);
+
+      gtk_tree_view_scroll_to_cell (GTK_TREE_VIEW (priv->treeview), path, NULL,
+          TRUE, 0, 0.5);
+
+      gtk_tree_path_free (path);
+    }
 }
 
 static void
