@@ -46,13 +46,13 @@
 
 #include <telepathy-logger/log-manager.h>
 
-#include <libempathy/empathy-idle.h>
+#include <libempathy/empathy-presence-manager.h>
 #include <libempathy/empathy-utils.h>
 #include <libempathy/empathy-chatroom-manager.h>
 #include <libempathy/empathy-account-settings.h>
 #include <libempathy/empathy-connectivity.h>
 #include <libempathy/empathy-connection-managers.h>
-#include <libempathy/empathy-dispatcher.h>
+#include <libempathy/empathy-request-util.h>
 #include <libempathy/empathy-ft-factory.h>
 #include <libempathy/empathy-gsettings.h>
 #include <libempathy/empathy-tp-chat.h>
@@ -109,12 +109,11 @@ struct _EmpathyApp
 
   GtkWidget *window;
   EmpathyStatusIcon *icon;
-  EmpathyDispatcher *dispatcher;
   TpAccountManager *account_manager;
   TplLogManager *log_manager;
   EmpathyChatroomManager *chatroom_manager;
   EmpathyFTFactory  *ft_factory;
-  EmpathyIdle *idle;
+  EmpathyPresenceManager *presence_mgr;
   EmpathyConnectivity *connectivity;
   GSettings *gsettings;
   EmpathyNotificationsApprover *notifications_approver;
@@ -136,21 +135,21 @@ empathy_app_dispose (GObject *object)
   void (*dispose) (GObject *) =
     G_OBJECT_CLASS (empathy_app_parent_class)->dispose;
 
-  if (self->idle != NULL)
+  if (self->presence_mgr != NULL)
     {
-      empathy_idle_set_state (self->idle, TP_CONNECTION_PRESENCE_TYPE_OFFLINE);
+      empathy_presence_manager_set_state (self->presence_mgr,
+          TP_CONNECTION_PRESENCE_TYPE_OFFLINE);
     }
 
 #ifdef ENABLE_DEBUG
   tp_clear_object (&self->debug_sender);
 #endif
 
-  tp_clear_object (&self->idle);
+  tp_clear_object (&self->presence_mgr);
   tp_clear_object (&self->connectivity);
   tp_clear_object (&self->icon);
   tp_clear_object (&self->account_manager);
   tp_clear_object (&self->log_manager);
-  tp_clear_object (&self->dispatcher);
   tp_clear_object (&self->chatroom_manager);
 #ifdef HAVE_GEOCLUE
   tp_clear_object (&self->location_manager);
@@ -520,7 +519,7 @@ account_manager_ready_cb (GObject *source_object,
           (presence, TP_CONNECTION_PRESENCE_TYPE_OFFLINE)
             <= 0)
       /* if current state is Offline, then put it online */
-      empathy_idle_set_state (self->idle,
+      empathy_presence_manager_set_state (self->presence_mgr,
           TP_CONNECTION_PRESENCE_TYPE_AVAILABLE);
 
   /* Pop up the accounts dialog if we don't have any account */
@@ -540,7 +539,7 @@ account_status_changed_cb (TpAccount *account,
   if (new_status != TP_CONNECTION_STATUS_CONNECTED)
     return;
 
-  empathy_dispatcher_join_muc (account,
+  empathy_join_muc (account,
       empathy_chatroom_get_room (room), TP_USER_ACTION_TIME_NOT_USER_ACTION);
 }
 
@@ -588,7 +587,7 @@ account_manager_chatroom_ready_cb (GObject *source_object,
             }
           else
             {
-              empathy_dispatcher_join_muc (account,
+              empathy_join_muc (account,
                   empathy_chatroom_get_room (room),
                   TP_USER_ACTION_TIME_NOT_USER_ACTION);
             }
@@ -612,13 +611,13 @@ chatroom_manager_ready_cb (EmpathyChatroomManager *chatroom_manager,
 }
 
 static void
-empathy_idle_set_auto_away_cb (GSettings *gsettings,
+empathy_presence_manager_set_auto_away_cb (GSettings *gsettings,
 				const gchar *key,
 				gpointer user_data)
 {
-	EmpathyIdle *idle = user_data;
+	EmpathyPresenceManager *presence_mgr = user_data;
 
-	empathy_idle_set_auto_away (idle,
+	empathy_presence_manager_set_auto_away (presence_mgr,
       g_settings_get_boolean (gsettings, key));
 }
 
@@ -643,16 +642,17 @@ empathy_app_constructed (GObject *object)
   notify_init (_(PACKAGE_NAME));
 
   /* Setting up Idle */
-  self->idle = empathy_idle_dup_singleton ();
+  self->presence_mgr = empathy_presence_manager_dup_singleton ();
 
   self->gsettings = g_settings_new (EMPATHY_PREFS_SCHEMA);
   autoaway = g_settings_get_boolean (self->gsettings, EMPATHY_PREFS_AUTOAWAY);
 
   g_signal_connect (self->gsettings,
       "changed::" EMPATHY_PREFS_AUTOAWAY,
-      G_CALLBACK (empathy_idle_set_auto_away_cb), self->idle);
+      G_CALLBACK (empathy_presence_manager_set_auto_away_cb),
+      self->presence_mgr);
 
-  empathy_idle_set_auto_away (self->idle, autoaway);
+  empathy_presence_manager_set_auto_away (self->presence_mgr, autoaway);
 
   /* Setting up Connectivity */
   self->connectivity = empathy_connectivity_dup_singleton ();
@@ -667,10 +667,6 @@ empathy_app_constructed (GObject *object)
   tp_account_manager_prepare_async (self->account_manager, NULL,
       account_manager_ready_cb, self);
 
-  /* The EmpathyDispatcher doesn't dispatch anything any more but we have to
-   * keep it around as we still use it to request channels */
-  self->dispatcher = empathy_dispatcher_dup_singleton ();
-
   migrate_config_to_xdg_dir ();
 
   /* Logging */
